@@ -18,9 +18,14 @@ __date__ = "2/4/13"
 import os
 import shutil
 import json
+import logging
+import tarfile
+import glob
 
 from custodian.custodian import ErrorHandler
 from pymatgen.io.vaspio.vasp_input import Incar, Poscar, VaspInput
+from pymatgen.transformations.standard_transformations import \
+    PerturbStructureTransformation
 from pymatgen.io.vaspio.vasp_output import Vasprun
 from custodian.ansible.intepreter import Modder
 
@@ -32,7 +37,8 @@ class VaspErrorHandler(ErrorHandler):
                 "Fatal error detecting k-mesh",
                 "Fatal error: unable to match k-point",
                 "Routine TETIRR needs special values"],
-        "inv_rot_mat": ["inverse of rotation matrix was not found (increase SYMPREC)"],
+        "inv_rot_mat": ["inverse of rotation matrix was not found (increase "
+                        "SYMPREC)"],
         "brmix": ["BRMIX: very serious problems"],
         "subspacematrix": ["WARNING: Sub-Space-Matrix is not hermitian in DAV"],
         "tetirr": ["Routine TETIRR needs special values"],
@@ -56,6 +62,7 @@ class VaspErrorHandler(ErrorHandler):
         return len(self.errors) > 0
 
     def correct(self):
+        backup()
         actions = []
         vi = VaspInput.from_directory(".")
         history = []
@@ -89,7 +96,9 @@ class VaspErrorHandler(ErrorHandler):
         history.append({'errors': list(self.errors), 'actions': actions})
         with open("corrections.json", "w") as f:
             json.dump(history, f, indent=4)
-        vi.write_input(".")
+        vi["INCAR"].write_file("INCAR")
+        vi["POSCAR"].write_file("POSCAR")
+        vi["KPOINTS"].write_file("KPOINTS")
 
     def __str__(self):
         return "Vasp error"
@@ -99,12 +108,16 @@ class UnconvergedErrorHandler(ErrorHandler):
     #todo: Make this work using ansible.
 
     def check(self):
-        v = Vasprun('vasprun.xml')
-        if not v.converged:
-            return True
+        try:
+            v = Vasprun('vasprun.xml')
+            if not v.converged:
+                return True
+        except:
+            return False
         return False
 
     def correct(self):
+        backup()
         shutil.copy("CONTCAR", "POSCAR")
         incar = Incar.from_file("INCAR")
         incar['ISTART'] = 1
@@ -121,13 +134,14 @@ class PoscarErrorHandler(ErrorHandler):
             output = f.read()
             for line in output.split("\n"):
                 l = line.strip()
-                if l.startswith("Found some non-integer element in rotation matrix"):
+                if l.startswith("Found some non-integer element in rotation "
+                                "matrix"):
                     return True
         return False
 
     def correct(self):
         #TODO: Add transformation applied to transformation.json if exists.
-        from pymatgen.transformations.standard_transformations import PerturbStructureTransformation
+        backup()
         shutil.copy("POSCAR", "POSCAR.orig")
         p = Poscar.from_file("POSCAR")
         s = p.struct
@@ -137,21 +151,15 @@ class PoscarErrorHandler(ErrorHandler):
         p.write_file("POSCAR")
 
 
-"""
-Aflow Error 9 (davidson)
-
-grep : "WARNING: Sub-Space-Matrix is not hermitian in DAV"
-fix : INCAR -> remove ALGO, IMIX, set ALGO=VERY_FAST
-
-Aflow Error 10 (nbands)
-
-grep : "BRMIX: very serious problems"
-fix :
-notes:
-aflow tries to get NBANDS from the OUTCAR
--> nbands=atoi(word.substr(word.find("NBANDS")+7).c_str());
-aflow then tries to get NBANDS from INCAR
-Then it increases NBANDS via
-nbands=nbands+5+nbands/5
-
-"""
+def backup():
+    error_num = 0
+    for f in glob.glob("error.*.tar.gz"):
+        toks = f.split(".")
+        error_num = max(error_num, int(toks[1]))
+    filename = "error.{}.tar.gz".format(error_num + 1)
+    logging.info("Backing up run to {}.".format(filename))
+    tar = tarfile.open(filename, "w:gz")
+    for f in os.listdir("."):
+        if not (f.startswith("error") and f.endswith(".tar.gz")):
+            tar.add(f)
+    tar.close()
\ No newline at end of file
