@@ -16,19 +16,17 @@ __date__ = "2/4/13"
 import logging
 
 from custodian.custodian import Custodian
-from pymatpro.custodian.handlers import IncarErrorHandler,\
-    KpointsErrorHandler, UnconvergedErrorHandler
-from pymatpro.custodian.jobs import BasicVaspJob, SecondRelaxationVaspJob
-
+from custodian.vasp.handlers import VaspErrorHandler, UnconvergedErrorHandler, PoscarErrorHandler
+from custodian.vasp.jobs import VaspJob
 
 def aflow_run():
     #An example of an aflow run.
 
     FORMAT = '%(asctime)s %(message)s'
     logging.basicConfig(format=FORMAT, level=logging.INFO, filename="run.log")
-    handlers = [IncarErrorHandler(), KpointsErrorHandler(),
-                UnconvergedErrorHandler()]
-    jobs = [BasicVaspJob(), SecondRelaxationVaspJob()]
+    handlers = [VaspErrorHandler(), UnconvergedErrorHandler(),
+                PoscarErrorHandler()]
+    jobs = VaspJob.aflow_style_run(["mpirun", "/share/apps/bin/pvasp.5.2.11"])
     c = Custodian(handlers, jobs, max_errors=10)
     c.run()
 
